import React from "react";
import {Button, DatePicker, Flex, Select, Space} from "antd";
import {usePathname, useRouter} from "next/navigation";
import {DetailModelForm} from "@/app/ui/task/project/DetailModelForm";
import {OPERATION_BUTTON_TYPE, taskStateList} from "@/app/lib/task/project/data";
import './TitleOperation.modules.css'
import dayjs from "dayjs";
interface TitleOperationProps {
    setTaskState: (value: string) => void;
    setExpectedStartTime:(value:string)=>void;
}


export const TitleOperation: React.FC<TitleOperationProps> = ({setTaskState,setExpectedStartTime}: TitleOperationProps) => {
    const {replace} = useRouter();
    const [currentPath, setCurrentPath] = React.useState(usePathname());
    const {RangePicker} = DatePicker;
    return <Space style={{marginTop:0}}>
            <DetailModelForm operationId={OPERATION_BUTTON_TYPE.ADD} description='添加主线任务'/>
            {currentPath.startsWith("/task/project") ?
                <>
                    <Button type="primary" onClick={() => {
                        replace("/task/four");
                        setCurrentPath("/task/four");
                    }}>四象限显示</Button>
                    <Button type="primary" onClick={() => {
                        replace("/task/list");
                        setCurrentPath("/task/list");
                    }}>列表展示</Button>
                </> :
                currentPath.startsWith("/task/list") ?
                    <>
                        <Button type="primary" onClick={() => {
                            replace("/task/project");
                            setCurrentPath("/task/project")
                        }}>任务树</Button>
                        <Button type="primary" onClick={() => {
                            replace("/task/four");
                            setCurrentPath("/task/four");
                        }}>四象限显示</Button>
                    </> : <>
                        <Button type="primary" onClick={() => {
                            replace("/task/project");
                            setCurrentPath("/task/project");
                        }}>任务树</Button>
                        <Button type="primary" onClick={() => {
                            replace("/task/list");
                            setCurrentPath("/task/list");
                        }}>列表展示</Button>
                    </>
            }
            {/*<AdvancedSearchForm/>*/}
            <span style={{whiteSpace: 'nowrap'}}>任务状态:</span>
            <Select
                mode="multiple"
                allowClear
                style={{minWidth: '100px'}}
                placeholder="任务状态"
                defaultValue={['8', '9']}
                onChange={(value) => {
                    console.log('onChange')
                    setTaskState(value.join(','))
                }}
                options={taskStateList.map(item => {
                    return {label: item.name, value: item.code}
                })}
            />
            <span style={{whiteSpace: 'nowrap'}}>期望开始时间范围:</span>
            <RangePicker
                placeholder={['开始时间','结束时间']}
                defaultValue={[dayjs().subtract(7,'day'),dayjs().add(7,'day')]}
                allowEmpty={[true, true]}
                onChange={(dates, dateStrings)=>{
                    console.log('onChange:',dates,dateStrings);
                    if(!dates){
                        setExpectedStartTime('')
                        return
                    }
                    let expectStartTimeList=[];
                    if (dates[0]) {
                        expectStartTimeList.push({'name':"expectedStartTime",'value':dates[0],'operateType':">="});
                    }
                    if (dates[1]) {
                        expectStartTimeList.push({'name':"expectedStartTime",'value':dates[1].add(1,'day'),'operateType':"<"})
                    }
                    setExpectedStartTime(JSON.stringify(expectStartTimeList))
                }}
                />
        </Space>
    {/*</Flex>*/}
}
